@@ -2,34 +2,26 @@
 """
 @Author  :   g1879
 @Contact :   g1879@qq.com
-@File    :   drission.py
 """
-from sys import exit
-from typing import Union
-
 from platform import system
+from sys import exit
+
 from requests import Session
-from requests.cookies import RequestsCookieJar
 from requests.structures import CaseInsensitiveDict
 from selenium import webdriver
 from selenium.common.exceptions import SessionNotCreatedException, WebDriverException
 from selenium.webdriver.chrome.options import Options
-from selenium.webdriver.chrome.webdriver import WebDriver
 from selenium.webdriver.remote.webdriver import WebDriver as RemoteWebDriver
 from tldextract import extract
 
 from .common import get_pid_from_port, connect_chrome
-from .config import _session_options_to_dict, SessionOptions, DriverOptions, _cookies_to_tuple
+from .config import SessionOptions, DriverOptions, cookies_to_tuple, session_options_to_dict
 
 
 class Drission(object):
     """Drission类用于管理WebDriver对象和Session对象，是驱动器的角色"""
 
-    def __init__(self,
-                 driver_or_options: Union[RemoteWebDriver, Options, DriverOptions, bool] = None,
-                 session_or_options: Union[Session, dict, SessionOptions, bool] = None,
-                 ini_path: str = None,
-                 proxy: dict = None):
+    def __init__(self, driver_or_options=None, session_or_options=None, ini_path=None, proxy=None):
         """初始化，可接收现成的WebDriver和Session对象，或接收它们的配置信息生成对象                     \n
         :param driver_or_options: driver对象或DriverOptions、Options类，传入False则创建空配置对象
         :param session_or_options: Session对象或设置字典，传入False则创建空配置对象
@@ -86,7 +78,7 @@ class Drission(object):
             pass
 
     @property
-    def session(self) -> Session:
+    def session(self):
         """返回Session对象，如未初始化则按配置信息创建"""
         if self._session is None:
             self._set_session(self._session_options)
@@ -97,7 +89,7 @@ class Drission(object):
         return self._session
 
     @property
-    def driver(self) -> WebDriver:
+    def driver(self):
         """返回WebDriver对象，如未初始化则按配置信息创建。         \n
         如设置了本地调试浏览器，可自动接入或打开浏览器进程。
         """
@@ -114,7 +106,7 @@ class Drission(object):
                 chrome_path, self._debugger = connect_chrome(self.driver_options)
 
             # -----------创建WebDriver对象-----------
-            self._driver = _create_driver(chrome_path, driver_path, self.driver_options)
+            self._driver = create_driver(chrome_path, driver_path, self.driver_options)
 
             # -----------解决接管新版浏览器不能定位到正确的标签页的问题-----------
             active_tab = self._driver.window_handles[0]
@@ -130,31 +122,31 @@ class Drission(object):
         return self._driver
 
     @property
-    def driver_options(self) -> Union[DriverOptions, Options]:
+    def driver_options(self):
         """返回driver配置信息"""
         return self._driver_options
 
     @property
-    def session_options(self) -> dict:
+    def session_options(self):
         """返回session配置信息"""
         return self._session_options
 
     @session_options.setter
-    def session_options(self, options: Union[dict, SessionOptions]) -> None:
+    def session_options(self, options):
         """设置session配置                  \n
         :param options: session配置字典
         :return: None
         """
-        self._session_options = _session_options_to_dict(options)
+        self._session_options = session_options_to_dict(options)
         self._set_session(self._session_options)
 
     @property
-    def proxy(self) -> Union[None, dict]:
+    def proxy(self):
         """返回代理信息"""
         return self._proxy
 
     @proxy.setter
-    def proxy(self, proxies: dict = None) -> None:
+    def proxy(self, proxies=None):
         """设置代理信息                \n
         :param proxies: 代理信息字典
         :return: None
@@ -180,13 +172,13 @@ class Drission(object):
         """调试浏览器进程"""
         return self._debugger
 
-    def kill_browser(self) -> None:
+    def kill_browser(self):
         """关闭浏览器进程（如果可以）"""
         pid = self.get_browser_progress_id()
-        if not _kill_progress(pid):
+        if not kill_progress(pid):
             self._driver.quit()
 
-    def get_browser_progress_id(self) -> Union[str, None]:
+    def get_browser_progress_id(self):
         """获取浏览器进程id"""
         if self.debugger_progress:
             return self.debugger_progress.pid
@@ -209,15 +201,15 @@ class Drission(object):
 
             return txt.split(' ')[-1]
 
-    def hide_browser(self) -> None:
+    def hide_browser(self):
         """隐藏浏览器界面"""
         self._show_or_hide_browser()
 
-    def show_browser(self) -> None:
+    def show_browser(self):
         """显示浏览器界面"""
         self._show_or_hide_browser(False)
 
-    def _show_or_hide_browser(self, hide: bool = True) -> None:
+    def _show_or_hide_browser(self, hide=True):
         if system().lower() != 'windows':
             raise OSError('该方法只能在Windows系统使用。')
 
@@ -231,22 +223,19 @@ class Drission(object):
         if not pid:
             print('只有设置了debugger_address参数才能使用 show_browser() 和 hide_browser()')
             return
-        hds = _get_chrome_hwnds_from_pid(pid)
+        hds = get_chrome_hwnds_from_pid(pid)
         sw = SW_HIDE if hide else SW_SHOW
         for hd in hds:
             ShowWindow(hd, sw)
 
-    def set_cookies(self,
-                    cookies: Union[RequestsCookieJar, list, tuple, str, dict],
-                    set_session: bool = False,
-                    set_driver: bool = False) -> None:
+    def set_cookies(self, cookies, set_session=False, set_driver=False):
         """设置cookies                                                      \n
         :param cookies: cookies信息，可为CookieJar, list, tuple, str, dict
         :param set_session: 是否设置session的cookies
         :param set_driver: 是否设置driver的cookies
         :return: None
         """
-        cookies = _cookies_to_tuple(cookies)
+        cookies = cookies_to_tuple(cookies)
 
         for cookie in cookies:
             if cookie['value'] is None:
@@ -296,7 +285,7 @@ class Drission(object):
 
                 self.driver.add_cookie(cookie)
 
-    def _set_session(self, data: dict) -> None:
+    def _set_session(self, data):
         """根据传入字典对session进行设置    \n
         :param data: session配置字典
         :return: None
@@ -315,7 +304,7 @@ class Drission(object):
             if i in data:
                 self._session.__setattr__(i, data[i])
 
-    def cookies_to_session(self, copy_user_agent: bool = False) -> None:
+    def cookies_to_session(self, copy_user_agent=False):
         """把driver对象的cookies复制到session对象    \n
         :param copy_user_agent: 是否复制ua信息
         :return: None
@@ -325,7 +314,7 @@ class Drission(object):
 
         self.set_cookies(self.driver.get_cookies(), set_session=True)
 
-    def cookies_to_driver(self, url: str) -> None:
+    def cookies_to_driver(self, url):
         """把session对象的cookies复制到driver对象  \n
         :param url: 作用域
         :return: None
@@ -348,10 +337,10 @@ class Drission(object):
 
         self.set_cookies(cookies, set_driver=True)
 
-    def close_driver(self, kill: bool = False) -> None:
+    def close_driver(self, kill=False):
         """关闭driver和浏览器"""
         if self._driver:
-            _kill_progress(port=self._driver.service.port)  # 关闭chromedriver.exe进程
+            kill_progress(port=self._driver.service.port)  # 关闭chromedriver.exe进程
 
             if kill:
                 self.kill_browser()
@@ -360,13 +349,13 @@ class Drission(object):
 
             self._driver = None
 
-    def close_session(self) -> None:
+    def close_session(self):
         """关闭session"""
         if self._session:
             self._session.close()
             self._session = None
 
-    def close(self) -> None:
+    def close(self):
         """关闭session、driver和浏览器"""
         if self._driver:
             self.close_driver()
@@ -375,7 +364,7 @@ class Drission(object):
             self.close_session()
 
 
-def user_agent_to_session(driver: RemoteWebDriver, session: Session) -> None:
+def user_agent_to_session(driver, session):
     """把driver的user-agent复制到session    \n
     :param driver: 来源driver对象
     :param session: 目标session对象
@@ -387,7 +376,7 @@ def user_agent_to_session(driver: RemoteWebDriver, session: Session) -> None:
     session.headers.update({"User-Agent": selenium_user_agent})
 
 
-def _create_driver(chrome_path: str, driver_path: str, options: Options) -> WebDriver:
+def create_driver(chrome_path, driver_path, options):
     """创建 WebDriver 对象                            \n
     :param chrome_path: chrome.exe 路径
     :param driver_path: chromedriver.exe 路径
@@ -424,7 +413,7 @@ def _create_driver(chrome_path: str, driver_path: str, options: Options) -> WebD
     exit(0)
 
 
-def _get_chrome_hwnds_from_pid(pid) -> list:
+def get_chrome_hwnds_from_pid(pid):
     """通过PID查询句柄ID"""
     try:
         from win32gui import IsWindow, GetWindowText, EnumWindows
@@ -444,7 +433,7 @@ def _get_chrome_hwnds_from_pid(pid) -> list:
     return hwnds
 
 
-def _kill_progress(pid: str = None, port: int = None) -> bool:
+def kill_progress(pid=None, port=None):
     """关闭浏览器进程                                 \n
     :param pid: 进程id
     :param port: 端口号，如没有进程id，从端口号获取
