@@ -2,14 +2,11 @@
 """
 @Author  :   g1879
 @Contact :   g1879@qq.com
-@File    :   session_element.py
 """
 from re import match, DOTALL
-from typing import Union, List, Tuple
 
 from lxml.etree import tostring
 from lxml.html import HtmlElement, fromstring
-# from lxml.etree import Element as HtmlElement, fromstring
 
 from .base import DrissionElement, BasePage, BaseElement
 from .common import get_ele_txt, get_loc, make_absolute_link
@@ -18,7 +15,7 @@ from .common import get_ele_txt, get_loc, make_absolute_link
 class SessionElement(DrissionElement):
     """session模式的元素对象，包装了一个lxml的Element对象，并封装了常用功能"""
 
-    def __init__(self, ele: HtmlElement, page=None):
+    def __init__(self, ele, page=None):
         """初始化对象                                                          \n
         :param ele: 被包装的HtmlElement元素
         :param page: 元素所在页面对象，如果是从 html 文本生成的元素，则为 None
@@ -27,16 +24,14 @@ class SessionElement(DrissionElement):
         self._inner_ele = ele
 
     @property
-    def inner_ele(self) -> HtmlElement:
+    def inner_ele(self):
         return self._inner_ele
 
-    def __repr__(self) -> str:
+    def __repr__(self):
         attrs = [f"{attr}='{self.attrs[attr]}'" for attr in self.attrs]
         return f'<SessionElement {self.tag} {" ".join(attrs)}>'
 
-    def __call__(self,
-                 loc_or_str: Union[Tuple[str, str], str],
-                 timeout=None) -> Union['SessionElement', str, None]:
+    def __call__(self, loc_or_str, timeout=None):
         """在内部查找元素                                                  \n
         例：ele2 = ele1('@id=ele_id')                                    \n
         :param loc_or_str: 元素的定位信息，可以是loc元组，或查询字符串
@@ -46,48 +41,45 @@ class SessionElement(DrissionElement):
         return self.ele(loc_or_str)
 
     @property
-    def tag(self) -> str:
+    def tag(self):
         """返回元素类型"""
         return self._inner_ele.tag
 
     @property
-    def html(self) -> str:
+    def html(self):
         """返回outerHTML文本"""
         html = tostring(self._inner_ele, method="html").decode()
         return html[:html.rfind('>') + 1]  # tostring()会把跟紧元素的文本节点也带上，因此要去掉
 
     @property
-    def inner_html(self) -> str:
+    def inner_html(self):
         """返回元素innerHTML文本"""
         r = match(r'<.*?>(.*)</.*?>', self.html, flags=DOTALL)
         return '' if not r else r.group(1)
 
     @property
-    def attrs(self) -> dict:
+    def attrs(self):
         """返回元素所有属性及值"""
         return {attr: self.attr(attr) for attr, val in self.inner_ele.items()}
 
     @property
-    def text(self) -> str:
+    def text(self):
         """返回元素内所有文本"""
         return get_ele_txt(self)
 
     @property
-    def raw_text(self) -> str:
+    def raw_text(self):
         """返回未格式化处理的元素内文本"""
         return str(self._inner_ele.text_content())
 
-    def parent(self, level_or_loc: Union[tuple, str, int] = 1) -> Union['SessionElement', None]:
+    def parent(self, level_or_loc=1):
         """返回上面某一级父元素，可指定层数或用查询语法定位              \n
         :param level_or_loc: 第几级父元素，或定位符
         :return: 上级元素对象
         """
         return super().parent(level_or_loc)
 
-    def prev(self,
-             index: int = 1,
-             filter_loc: Union[tuple, str] = '',
-             timeout: float = 0) -> Union['SessionElement', str, None]:
+    def prev(self, index=1, filter_loc='', timeout=0):
         """返回前面的一个兄弟元素，可用查询语法筛选，可指定返回筛选结果的第几个        \n
         :param index: 前面第几个查询结果元素
         :param filter_loc: 用于筛选元素的查询语法
@@ -96,10 +88,7 @@ class SessionElement(DrissionElement):
         """
         return super().prev(index, filter_loc, timeout)
 
-    def next(self,
-             index: int = 1,
-             filter_loc: Union[tuple, str] = '',
-             timeout: float = 0) -> Union['SessionElement', str, None]:
+    def next(self, index=1, filter_loc='', timeout=0):
         """返回后面的一个兄弟元素，可用查询语法筛选，可指定返回筛选结果的第几个        \n
         :param index: 后面第几个查询结果元素
         :param filter_loc: 用于筛选元素的查询语法
@@ -108,10 +97,7 @@ class SessionElement(DrissionElement):
         """
         return super().next(index, filter_loc, timeout)
 
-    def before(self,
-               index: int = 1,
-               filter_loc: Union[tuple, str] = '',
-               timeout: float = None) -> Union['SessionElement', str, None]:
+    def before(self, index=1, filter_loc='', timeout=None):
         """返回前面的一个兄弟元素，可用查询语法筛选，可指定返回筛选结果的第几个        \n
         :param index: 前面第几个查询结果元素
         :param filter_loc: 用于筛选元素的查询语法
@@ -120,10 +106,7 @@ class SessionElement(DrissionElement):
         """
         return super().before(index, filter_loc, timeout)
 
-    def after(self,
-              index: int = 1,
-              filter_loc: Union[tuple, str] = '',
-              timeout: float = None) -> Union['SessionElement', str, None]:
+    def after(self, index=1, filter_loc='', timeout=None):
         """返回后面的一个兄弟元素，可用查询语法筛选，可指定返回筛选结果的第几个        \n
         :param index: 后面第几个查询结果元素
         :param filter_loc: 用于筛选元素的查询语法
@@ -132,9 +115,7 @@ class SessionElement(DrissionElement):
         """
         return super().after(index, filter_loc, timeout)
 
-    def prevs(self,
-              filter_loc: Union[tuple, str] = '',
-              timeout: float = 0) -> List[Union['SessionElement', str]]:
+    def prevs(self, filter_loc='', timeout=0):
         """返回前面全部兄弟元素或节点组成的列表，可用查询语法筛选        \n
         :param filter_loc: 用于筛选元素的查询语法
         :param timeout: 查找元素的超时时间
@@ -142,9 +123,7 @@ class SessionElement(DrissionElement):
         """
         return super().prevs(filter_loc, timeout)
 
-    def nexts(self,
-              filter_loc: Union[tuple, str] = '',
-              timeout: float = 0) -> List[Union['SessionElement', str]]:
+    def nexts(self, filter_loc='', timeout=0):
         """返回后面全部兄弟元素或节点组成的列表，可用查询语法筛选        \n
         :param filter_loc: 用于筛选元素的查询语法
         :param timeout: 查找元素的超时时间
@@ -152,9 +131,7 @@ class SessionElement(DrissionElement):
         """
         return super().nexts(filter_loc, timeout)
 
-    def befores(self,
-                filter_loc: Union[tuple, str] = '',
-                timeout: float = None) -> List[Union['SessionElement', str]]:
+    def befores(self, filter_loc='', timeout=None):
         """返回后面全部兄弟元素或节点组成的列表，可用查询语法筛选        \n
         :param filter_loc: 用于筛选元素的查询语法
         :param timeout: 查找元素的超时时间
@@ -162,9 +139,7 @@ class SessionElement(DrissionElement):
         """
         return super().befores(filter_loc, timeout)
 
-    def afters(self,
-               filter_loc: Union[tuple, str] = '',
-               timeout: float = None) -> List[Union['SessionElement', str]]:
+    def afters(self, filter_loc='', timeout=None):
         """返回前面全部兄弟元素或节点组成的列表，可用查询语法筛选        \n
         :param filter_loc: 用于筛选元素的查询语法
         :param timeout: 查找元素的超时时间
@@ -172,7 +147,7 @@ class SessionElement(DrissionElement):
         """
         return super().afters(filter_loc, timeout)
 
-    def attr(self, attr: str) -> Union[str, None]:
+    def attr(self, attr):
         """返回attribute属性值                           \n
         :param attr: 属性名
         :return: 属性值文本，没有该属性返回None
@@ -205,9 +180,7 @@ class SessionElement(DrissionElement):
         else:
             return self.inner_ele.get(attr)
 
-    def ele(self,
-            loc_or_str: Union[Tuple[str, str], str],
-            timeout=None) -> Union['SessionElement', str, None]:
+    def ele(self, loc_or_str, timeout=None):
         """返回当前元素下级符合条件的第一个元素、属性或节点文本                      \n
         :param loc_or_str: 元素的定位信息，可以是loc元组，或查询字符串
         :param timeout: 不起实际作用，用于和DriverElement对应，便于无差别调用
@@ -215,9 +188,7 @@ class SessionElement(DrissionElement):
         """
         return self._ele(loc_or_str)
 
-    def eles(self,
-             loc_or_str: Union[Tuple[str, str], str],
-             timeout=None) -> List[Union['SessionElement', str]]:
+    def eles(self, loc_or_str, timeout=None):
         """返回当前元素下级所有符合条件的子元素、属性或节点文本                       \n
         :param loc_or_str: 元素的定位信息，可以是loc元组，或查询字符串
         :param timeout: 不起实际作用，用于和DriverElement对应，便于无差别调用
@@ -225,27 +196,21 @@ class SessionElement(DrissionElement):
         """
         return self._ele(loc_or_str, single=False)
 
-    def s_ele(self,
-              loc_or_str: Union[Tuple[str, str], str] = None) -> Union['SessionElement', str, None]:
+    def s_ele(self, loc_or_str=None):
         """返回当前元素下级符合条件的第一个元素、属性或节点文本                       \n
         :param loc_or_str: 元素的定位信息，可以是loc元组，或查询字符串
         :return: SessionElement对象或属性、文本
         """
         return self._ele(loc_or_str)
 
-    def s_eles(self,
-               loc_or_str: Union[Tuple[str, str], str] = None) -> List[Union['SessionElement', str]]:
+    def s_eles(self, loc_or_str=None):
         """返回当前元素下级所有符合条件的子元素、属性或节点文本                       \n
         :param loc_or_str: 元素的定位信息，可以是loc元组，或查询字符串
         :return: SessionElement对象或属性、文本组成的列表
         """
         return self._ele(loc_or_str, single=False)
 
-    def _ele(self,
-             loc_or_str: Union[Tuple[str, str], str],
-             timeout=None,
-             single: bool = True,
-             relative: bool = False) -> Union['SessionElement', str, None, List[Union['SessionElement', str]]]:
+    def _ele(self, loc_or_str, timeout=None, single=True, relative=False):
         """返回当前元素下级符合条件的子元素、属性或节点文本，默认返回第一个           \n
         :param loc_or_str: 元素的定位信息，可以是loc元组，或查询字符串
         :param timeout: 不起实际作用，用于和父类对应
@@ -255,7 +220,7 @@ class SessionElement(DrissionElement):
         """
         return make_session_ele(self, loc_or_str, single)
 
-    def _get_ele_path(self, mode) -> str:
+    def _get_ele_path(self, mode):
         """获取css路径或xpath路径
         :param mode: 'css' 或 'xpath'
         :return: css路径或xpath路径
@@ -276,9 +241,7 @@ class SessionElement(DrissionElement):
         return f':root{path_str[1:]}' if mode == 'css' else path_str
 
 
-def make_session_ele(html_or_ele: Union[str, BaseElement, BasePage],
-                     loc: Union[str, Tuple[str, str]] = None,
-                     single: bool = True) -> Union[SessionElement, str, None, List[Union[SessionElement, str]]]:
+def make_session_ele(html_or_ele, loc=None, single=True):
     """从接收到的对象或html文本中查找元素，返回SessionElement对象                 \n
     如要直接从html生成SessionElement而不在下级查找，loc输入None即可               \n
     :param html_or_ele: html文本、BaseParser对象
@@ -300,7 +263,8 @@ def make_session_ele(html_or_ele: Union[str, BaseElement, BasePage],
         raise ValueError("定位符必须为str或长度为2的tuple。")
 
     # ---------------根据传入对象类型获取页面对象和lxml元素对象---------------
-    if isinstance(html_or_ele, SessionElement):  # SessionElement
+    the_type = str(type(html_or_ele))
+    if the_type.endswith(".SessionElement'>"):  # SessionElement
         page = html_or_ele.page
 
         loc_str = loc[1]
@@ -321,7 +285,7 @@ def make_session_ele(html_or_ele: Union[str, BaseElement, BasePage],
 
         loc = loc[0], loc_str
 
-    elif isinstance(html_or_ele, DrissionElement):  # DriverElement
+    elif the_type.endswith((".ChromiumElement'>", ".DriverElement'>")):  # ChromiumElement, DriverElement
         loc_str = loc[1]
         if loc[0] == 'xpath' and loc[1].lstrip().startswith('/'):
             loc_str = f'.{loc[1]}'
@@ -332,10 +296,14 @@ def make_session_ele(html_or_ele: Union[str, BaseElement, BasePage],
         # 获取整个页面html再定位到当前元素，以实现查找上级元素
         page = html_or_ele.page
         xpath = html_or_ele.xpath
-        html_or_ele = fromstring(html_or_ele.page.html)
+        if hasattr(html_or_ele, 'doc_id'):  # ChromiumElement，兼容传入的元素在iframe内的情况
+            html = html_or_ele.page.run_cdp('DOM.getOuterHTML', objectId=html_or_ele.doc_id)['outerHTML']
+        else:
+            html = html_or_ele.page.html
+        html_or_ele = fromstring(html)
         html_or_ele = html_or_ele.xpath(xpath)[0]
 
-    elif isinstance(html_or_ele, BasePage):  # MixPage, DriverPage 或 SessionPage
+    elif isinstance(html_or_ele, BasePage):  # 各种页面对象
         page = html_or_ele
         html_or_ele = fromstring(html_or_ele.html)
 
@@ -343,7 +311,8 @@ def make_session_ele(html_or_ele: Union[str, BaseElement, BasePage],
         page = None
         html_or_ele = fromstring(html_or_ele)
 
-    elif isinstance(html_or_ele, BaseElement):  # ShadowRootElement
+    # ShadowRootElement, ChromiumShadowRootElement, ChromiumFrame
+    elif isinstance(html_or_ele, BaseElement) or the_type.endswith(".ChromiumFrame'>"):
         page = html_or_ele.page
         html_or_ele = fromstring(html_or_ele.html)
 
